==> apache-doris-3.0.8-rc01-src.tar.gz: apache-doris-3.0.8-rc01-src/fe/fe-core/src/main/java/org/apache/doris/nereids/trees/plans/BlockFuncDepsPropagation.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.trees.plans;

import org.apache.doris.nereids.properties.DataTrait;
import org.apache.doris.nereids.trees.plans.logical.LogicalPlan;

/**
 * Block fd propagation, it always returns an empty fd
 */
public interface BlockFuncDepsPropagation extends LogicalPlan {
    @Override
    default DataTrait computeDataTrait() {
        return DataTrait.EMPTY_TRAIT;
    }

    @Override
    default void computeUnique(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeUniform(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeEqualSet(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeFd(DataTrait.Builder builder) {
        // don't generate
    }
}

==> apache-doris-4.0.3-rc03-src.tar.gz: apache-doris-4.0.3-rc03-src/fe/fe-core/src/main/java/org/apache/doris/nereids/trees/plans/BlockFuncDepsPropagation.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.trees.plans;

import org.apache.doris.nereids.properties.DataTrait;

/**
 * Block fd propagation, it always returns an empty fd
 */
public interface BlockFuncDepsPropagation extends Plan {
    @Override
    default DataTrait computeDataTrait() {
        return DataTrait.EMPTY_TRAIT;
    }

    @Override
    default void computeUnique(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeUniform(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeEqualSet(DataTrait.Builder builder) {
        // don't generate
    }

    @Override
    default void computeFd(DataTrait.Builder builder) {
        // don't generate
    }
}
